@@ -38,7 +38,8 @@ class Assistant:
 
         logger.debug("Data for agent creation: %s", data)
         logger.info("App type: %s", app_type)
-        
+
+        self.alita_client = alita
         self.client = client
         # For predict agents, use the client as-is since it's already configured
         # if app_type == "predict":
@@ -176,6 +177,34 @@ class Assistant:
         # Exclude compiled graph runnables from simple tool agents
         simple_tools = [t for t in self.tools if isinstance(t, (BaseTool, CompiledStateGraph))]
         
+        # Add sandbox tool by default for react agents
+        try:
+            from ..tools.sandbox import create_sandbox_tool
+            sandbox_tool = create_sandbox_tool(stateful=False, allow_net=True)
+            simple_tools.append(sandbox_tool)
+            logger.info("Added PyodideSandboxTool to react agent")
+        except ImportError as e:
+            logger.warning(f"Failed to add PyodideSandboxTool: {e}. Install langchain-sandbox to enable this feature.")
+        except RuntimeError as e:
+            if "Deno" in str(e):
+                logger.warning("Failed to add PyodideSandboxTool: Deno is required. Install from https://docs.deno.com/runtime/getting_started/installation/")
+            else:
+                logger.warning(f"Failed to add PyodideSandboxTool: {e}")
+        except Exception as e:
+            logger.error(f"Error adding PyodideSandboxTool: {e}")
+        
+        # Add image generation tool if model is configured
+        if self.alita_client.model_image_generation is not None:
+            try:
+                from ..tools.image_generation import (
+                    create_image_generation_tool
+                )
+                image_tool = create_image_generation_tool(self.alita_client)
+                simple_tools.append(image_tool)
+                logger.info("Added ImageGenerationTool to react agent")
+            except Exception as e:
+                logger.error(f"Error adding ImageGenerationTool: {e}")
+        
         # Set up memory/checkpointer if available
         checkpointer = None
         if self.memory is not None:
